# Generated by Django 5.1.4 on 2025-01-02 07:44

from __future__ import annotations

from django.db import migrations
from django.db import models


class Migration(migrations.Migration):
    dependencies = [
        ("django_qstash_schedules", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="taskschedule",
            name="updated_at",
            field=models.DateTimeField(auto_now=True),
        ),
    ]
