# Generated by Django 5.1.4 on 2025-01-13 19:27

from __future__ import annotations

from django.db import migrations
from django.db import models

import django_qstash.schedules.validators


class Migration(migrations.Migration):
    dependencies = [
        ("django_qstash_schedules", "0002_taskschedule_updated_at"),
    ]

    operations = [
        migrations.AlterField(
            model_name="taskschedule",
            name="cron",
            field=models.CharField(
                default="*/5 * * * *",
                help_text="Cron expression for scheduling the task",
                max_length=255,
                validators=[
                    django_qstash.schedules.validators.validate_cron_expression
                ],
                verbose_name="Cron Expression",
            ),
        ),
    ]
