# Generated by Django 5.1.4 on 2025-01-06 05:39

from __future__ import annotations

from django.db import migrations
from django.db import models


class Migration(migrations.Migration):
    dependencies = [
        ("django_qstash_results", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="taskresult",
            name="function_path",
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="taskresult",
            name="status",
            field=models.CharField(
                choices=[
                    ("PENDING", "Pending"),
                    ("SUCCESS", "Success"),
                    ("EXECUTION_ERROR", "Execution Error"),
                    ("INTERNAL_ERROR", "Internal Error"),
                    ("OTHER_ERROR", "Other Error"),
                    ("UNKNOWN", "Unknown"),
                ],
                default="PENDING",
                max_length=50,
            ),
        ),
        migrations.AlterField(
            model_name="taskresult",
            name="task_id",
            field=models.CharField(db_index=True, max_length=255),
        ),
        migrations.AlterField(
            model_name="taskresult",
            name="traceback",
            field=models.TextField(blank=True, null=True),
        ),
    ]
